==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/enums/AutomationRulePropertyChangedConditionSupportedPropertyType.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

public enum class AutomationRulePropertyChangedConditionSupportedPropertyType(
    public val javaValue:
    com.pulumi.azurenative.securityinsights.enums.AutomationRulePropertyChangedConditionSupportedPropertyType,
) :
    ConvertibleToJava<com.pulumi.azurenative.securityinsights.enums.AutomationRulePropertyChangedConditionSupportedPropertyType> {
    /**
     * Evaluate the condition on the incident severity
     */
    IncidentSeverity(com.pulumi.azurenative.securityinsights.enums.AutomationRulePropertyChangedConditionSupportedPropertyType.IncidentSeverity),

    /**
     * Evaluate the condition on the incident status
     */
    IncidentStatus(com.pulumi.azurenative.securityinsights.enums.AutomationRulePropertyChangedConditionSupportedPropertyType.IncidentStatus),

    /**
     * Evaluate the condition on the incident owner
     */
    IncidentOwner(com.pulumi.azurenative.securityinsights.enums.AutomationRulePropertyChangedConditionSupportedPropertyType.IncidentOwner),
    ;

    override fun toJava():
        com.pulumi.azurenative.securityinsights.enums.AutomationRulePropertyChangedConditionSupportedPropertyType =
        javaValue

    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.securityinsights.enums.AutomationRulePropertyChangedConditionSupportedPropertyType):
            AutomationRulePropertyChangedConditionSupportedPropertyType =
            AutomationRulePropertyChangedConditionSupportedPropertyType.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/enums/AutomationRulePropertyChangedConditionSupportedPropertyType.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

public enum class AutomationRulePropertyChangedConditionSupportedPropertyType(
    public val javaValue: com.pulumi.azurenative.securityinsights.enums.AutomationRulePropertyChangedConditionSupportedPropertyType,
) :
    ConvertibleToJava<com.pulumi.azurenative.securityinsights.enums.AutomationRulePropertyChangedConditionSupportedPropertyType> {
    /**
     * Evaluate the condition on the incident severity
     */
    IncidentSeverity(com.pulumi.azurenative.securityinsights.enums.AutomationRulePropertyChangedConditionSupportedPropertyType.IncidentSeverity),

    /**
     * Evaluate the condition on the incident status
     */
    IncidentStatus(com.pulumi.azurenative.securityinsights.enums.AutomationRulePropertyChangedConditionSupportedPropertyType.IncidentStatus),

    /**
     * Evaluate the condition on the incident owner
     */
    IncidentOwner(com.pulumi.azurenative.securityinsights.enums.AutomationRulePropertyChangedConditionSupportedPropertyType.IncidentOwner),
    ;

    override fun toJava(): com.pulumi.azurenative.securityinsights.enums.AutomationRulePropertyChangedConditionSupportedPropertyType = javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.securityinsights.enums.AutomationRulePropertyChangedConditionSupportedPropertyType): AutomationRulePropertyChangedConditionSupportedPropertyType =
            AutomationRulePropertyChangedConditionSupportedPropertyType.values().first { it.javaValue == javaType }
    }
}
